@@ -10,6 +10,7 @@ from copy import deepcopy
 from ast import literal_eval
 
 from math import pi
+from collections import OrderedDict
 
 from compas.utilities import average
 
@@ -62,6 +63,7 @@ from compas.datastructures._mixins import VertexMappings
 from compas.datastructures._mixins import EdgeMappings
 from compas.datastructures._mixins import FaceMappings
 
+import sys
 
 __all__ = ['Mesh']
 
@@ -624,7 +626,7 @@ class Mesh(FromToPickle,
         -------
         Mesh
             A mesh object.
-            
+
         """
 
         corner_vertices = [geometric_key(xyz) for polyline in boundary_polylines + other_polylines for xyz in [polyline[0], polyline[-1]]]
@@ -640,7 +642,7 @@ class Mesh(FromToPickle,
         for fkey in mesh.faces():
             if sum([geometric_key(mesh.vertex_coordinates(vkey)) not in boundary_vertices for vkey in mesh.face_vertices(fkey)]):
                 faces.append([vertex_map[vkey] for vkey in mesh.face_vertices(fkey) if geometric_key(mesh.vertex_coordinates(vkey)) in corner_vertices])
-        
+
         mesh.cull_vertices()
 
         return cls.from_vertices_and_faces(vertices, faces)
@@ -678,14 +680,19 @@ class Mesh(FromToPickle,
         """
         mesh = cls()
 
-        if isinstance(vertices, collections.Mapping):
+        if sys.version_info[0] < 3:
+            mapping = collections.Mapping
+        else:
+            mapping = collections.abc.Mapping
+
+        if isinstance(vertices, mapping):
             for key, xyz in vertices.items():
                 mesh.add_vertex(key = key, attr_dict = {i: j for i, j in zip(['x', 'y', 'z'], xyz)})
         else:
             for x, y, z in iter(vertices):
                 mesh.add_vertex(x=x, y=y, z=z)
 
-        if isinstance(faces, collections.Mapping):
+        if isinstance(faces, mapping):
             for fkey, vertices in faces.items():
                 mesh.add_face(vertices, fkey)
         else:
@@ -744,7 +751,7 @@ class Mesh(FromToPickle,
             pass
 
         """
-        from compas.topology import delaunay_from_points
+        from compas.geometry import delaunay_from_points
         faces = delaunay_from_points(points, boundary=boundary, holes=holes)
         return cls.from_vertices_and_faces(points, faces)
 
@@ -1333,7 +1340,7 @@ class Mesh(FromToPickle,
                 if self.halfedge[u][v] is None and self.halfedge[v][u] is None:
                     return False
                 fkey = self.halfedge[u][v]
-                if fkey:
+                if fkey is not None:
                     if fkey not in self.face:
                         return False
 
@@ -2087,7 +2094,7 @@ class Mesh(FromToPickle,
         boundaries = []
 
         # get all boundary edges pointing outwards
-        boundary_edges = {u: v for u, v in self.edges_on_boundary()}
+        boundary_edges = OrderedDict([(u, v) for u, v in self.edges_on_boundary(True)])
 
         # start new boundary
         while len(boundary_edges) > 0:
@@ -2290,8 +2297,8 @@ class Mesh(FromToPickle,
             return 0
         return max(self.face_degree(fkey) for fkey in self.faces())
 
-    def face_vertex_ancestor(self, fkey, key):
-        """Return the vertex before the specified vertex in a specific face.
+    def face_vertex_ancestor(self, fkey, key, n=1):
+        """Return the n-th vertex before the specified vertex in a specific face.
 
         Parameters
         ----------
@@ -2299,6 +2306,8 @@ class Mesh(FromToPickle,
             Identifier of the face.
         key : hashable
             The identifier of the vertex.
+        n : int, optional
+            The index of the vertex ancestor. Default is 1, meaning the previous vertex.
 
         Returns
         -------
@@ -2312,10 +2321,10 @@ class Mesh(FromToPickle,
 
         """
         i = self.face[fkey].index(key)
-        return self.face[fkey][i - 1]
+        return self.face[fkey][(i - n) % len(self.face[fkey])]
 
-    def face_vertex_descendant(self, fkey, key):
-        """Return the vertex after the specified vertex in a specific face.
+    def face_vertex_descendant(self, fkey, key, n=1):
+        """Return the n-th vertex after the specified vertex in a specific face.
 
         Parameters
         ----------
@@ -2323,6 +2332,8 @@ class Mesh(FromToPickle,
             Identifier of the face.
         key : hashable
             The identifier of the vertex.
+        n : int, optional
+            The index of the vertex descendant. Default is 1, meaning the next vertex.
 
         Returns
         -------
@@ -2335,10 +2346,8 @@ class Mesh(FromToPickle,
             If the vertex is not part of the face.
 
         """
-        if self.face[fkey][-1] == key:
-            return self.face[fkey][0]
         i = self.face[fkey].index(key)
-        return self.face[fkey][i + 1]
+        return self.face[fkey][(i + n) % len(self.face[fkey])]
 
     def face_adjacency_halfedge(self, f1, f2):
         """Find one half-edge over which two faces are adjacent.
@@ -2568,7 +2577,7 @@ class Mesh(FromToPickle,
             The coordinates of the centroid.
 
         """
-        return centroid_points([self.vertex_coordinates(nbr) for nbr in self.neighbors(key)])
+        return centroid_points([self.vertex_coordinates(nbr) for nbr in self.vertex_neighbors(key)])
 
     def vertex_normal(self, key):
         """Return the normal vector at the vertex as the weighted average of the
@@ -2609,7 +2618,11 @@ class Mesh(FromToPickle,
 
         """
 
-        return 2 * pi - sum([angle_points(mesh.vertex_coordinates(vkey), mesh.vertex_coordinates(u), mesh.vertex_coordinates(v)) for u, v in pairwise(self.vertex_neighbors(vkey, ordered = True) + self.vertex_neighbors(vkey, ordered = True)[:1])])
+        Sum = 0
+        for u, v in pairwise(self.vertex_neighbors(vkey, ordered=True) + self.vertex_neighbors(vkey, ordered=True)[:1]):
+            Sum += angle_points(self.vertex_coordinates(vkey), self.vertex_coordinates(u), self.vertex_coordinates(v))
+
+        return 2 * pi - Sum
 
     # --------------------------------------------------------------------------
     # edge geometry
@@ -2921,20 +2934,22 @@ class Mesh(FromToPickle,
             The faces on the boundary.
 
         """
-        faces = {}
+        faces = OrderedDict()
         for key, nbrs in iter(self.halfedge.items()):
             for nbr, fkey in iter(nbrs.items()):
                 if fkey is None:
                     faces[self.halfedge[nbr][key]] = 1
         return faces.keys()
 
-    def edges_on_boundary(self, oriented=True):
+    def edges_on_boundary(self, chained=False):
         """Find the edges on the boundary.
 
         Parameters
         ----------
-        oriented : bool
-            Boolean whether the boundary edges should point outwards.
+        chained : bool (``False``)
+            Indicate whether the boundary edges should be chained head to tail.
+            Note that chaining the edges will essentially return half-edges that
+            point outwards to the space outside.
 
         Returns
         -------
@@ -2942,12 +2957,14 @@ class Mesh(FromToPickle,
             The boundary edges.
 
         """
+
+        # TODO: perhaps split into two functions
         boundary_edges =  [(u, v) for u, v in self.edges() if self.is_edge_on_boundary(u, v)]
 
-        if not oriented:
+        if not chained:
             return boundary_edges
-        else:
-            return [(u, v) if self.halfedge[u][v] is None else (v, u) for u, v in boundary_edges]
+
+        return [(u, v) if self.halfedge[u][v] is None else (v, u) for u, v in boundary_edges]
 
     # --------------------------------------------------------------------------
     # attributes
