@@ -145,7 +145,7 @@ def dr(vertices, edges, fixed, loads, qpre, fpre, lpre, linit, E, radius,
 
         import compas
         from compas.datastructures import Network
-        from compas.plotters import NetworkPlotter
+        from compas_plotters import NetworkPlotter
         from compas.utilities import i_to_rgb
         from compas.numerical import dr
 
@@ -390,7 +390,7 @@ if __name__ == "__main__":
 
     import compas
     from compas.datastructures import Network
-    from compas.plotters import NetworkPlotter
+    from compas_plotters import NetworkPlotter
     from compas.numerical import dr
     from compas.utilities import i_to_rgb
 
