@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.robots
+robots
 ********************************************************************************
 
 .. currentmodule:: compas.robots
