@@ -1,7 +1,10 @@
+from __future__ import absolute_import
+from __future__ import division
 from __future__ import print_function
 
 from compas_ghpython.artists import MeshArtist
 
+
 __all__ = [
     'mesh_draw',
     'mesh_draw_vertices',
@@ -37,7 +40,7 @@ def mesh_draw(mesh, color=None):
     """
 
     artist = MeshArtist(mesh)
-    return artist.draw(color)
+    return artist.draw_mesh(color)
 
 
 def mesh_draw_vertices(mesh,
